package com.sooka.apply.mapper;

import java.util.List;
import com.sooka.apply.domain.IntRecord;
import com.sooka.apply.domain.IntDetailed;
import org.apache.ibatis.annotations.Param;

/**
 * 申请记录Mapper接口
 *
 * @author yhliang
 * @date 2021-07-06
 */
public interface IntRecordMapper
{
    /**
     * 查询申请记录
     *
     * @param id 申请记录ID
     * @return 申请记录
     */
    public IntRecord selectIntRecordById(String id);

    /**
     * 查询申请子表记录
     *
     * @param subId 申请子表记录ID
     * @return 申请记录
     */
    public IntDetailed selectIntRecordDetailedBySubId(String subId);

    /**
     * 查询申请记录列表
     *
     * @param intRecord 申请记录
     * @return 申请记录集合
     */
    public List<IntRecord> selectIntRecordList(IntRecord intRecord);

    /**
     * 查询申请记录明细
     *
     * @param intDetailed 查询条件
     * @return 申请明细集合
     */
    public List<IntDetailed> selectIntDetailedList(IntDetailed intDetailed);


    /**
     * 新增申请记录
     *
     * @param intRecord 申请记录
     * @return 结果
     */
    public int insertIntRecord(IntRecord intRecord);

    /**
     * 修改申请记录
     *
     * @param intBo 申请记录
     * @return 结果
     */
    public int editIntRecord(IntRecord intBo);

    /**
     * 批量删除申请记录
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteIntRecordByIds(String[] ids);

    /**
     * 批量删除申请明细
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteIntDetailedByRecordIds(String[] ids);

    /**
     * 批量新增申请明细
     *
     * @param intDetailedList 申请明细列表
     * @return 结果
     */
    public int batchIntDetailed(List<IntDetailed> intDetailedList);

    /**
     * 状态修改
     *
     * @param intDetailed 接口信息
     * @return 结果
     */
    public int changeStatus(IntDetailed intDetailed);

    /**
     * 提交审核
     * @return 结果
     */
    public int updateStatus(@Param("id") String id, @Param("status") String status);


}
