package com.sooka.apply.service;

import java.util.List;

import com.sooka.apply.domain.IntBo;
import com.sooka.apply.domain.IntDetailed;
import com.sooka.apply.domain.IntRecord;

/**
 * 申请记录Service接口
 *
 * @author yhliang
 * @date 2021-07-06
 */
public interface IIntRecordService
{
    /**
     * 查询申请记录
     *
     * @param id 申请记录ID
     * @return 申请记录
     */
    public IntRecord selectIntRecordById(String id);

    /**
     * 查询申请子表记录
     *
     * @param subId 申请子表记录ID
     * @return 申请记录
     */
    public IntDetailed selectIntRecordDetailedBySubId(String subId);

    /**
     * 查询申请记录列表
     *
     * @param intRecord 申请记录
     * @return 申请记录集合
     */
    public List<IntRecord> selectIntRecordList(IntRecord intRecord);

    /**
     * 查询申请记录明细
     *
     * @param intDetailed 查询条件
     * @return 申请明细集合
     */
    public List<IntDetailed> selectIntDetailedList(IntDetailed intDetailed);

    /**
     * 新增申请记录
     *
     * @param intBo 申请记录
     * @return 结果
     */
    public int insertIntRecord(IntRecord intBo);

    /**
     * 修改申请记录
     *
     * @param intBo 申请记录
     * @return 结果
     */
    public int editIntRecord(IntRecord intBo);

    /**
     * 保存驳回信息字段
     */
    public int rejectIntRecord(IntRecord intBo);

    /**
     * 批量删除申请记录
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteIntRecordByIds(String ids);

    /**
     * 状态修改
     *
     * @param intDetailed 接口信息
     * @return 结果
     */
    public int changeStatus(IntDetailed intDetailed);

    /**
     * 提交审核
     * @return 结果
     */
    public int updateStatus(String id, String status);

}
