package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjDwxx;
import com.sooka.system.service.ITgjjDwxxService;

/**
 * 单位信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/dwxx")
public class TgjjDwxxController extends BaseController
{
    private String prefix = "system/dwxx";

    @Autowired
    private ITgjjDwxxService tgjjDwxxService;

    @RequiresPermissions("system:dwxx:view")
    @GetMapping()
    public String dwxx()
    {
        return prefix + "/dwxx";
    }

    /**
     * 查询单位信息列表
     */
    @RequiresPermissions("system:dwxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjDwxx tgjjDwxx)
    {
        startPage();
        List<TgjjDwxx> list = tgjjDwxxService.selectTgjjDwxxList(tgjjDwxx);
        return getDataTable(list);
    }

    /**
     * 导出单位信息列表
     */
    @RequiresPermissions("system:dwxx:export")
    @Log(title = "单位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjDwxx tgjjDwxx)
    {
        List<TgjjDwxx> list = tgjjDwxxService.selectTgjjDwxxList(tgjjDwxx);
        ExcelUtil<TgjjDwxx> util = new ExcelUtil<TgjjDwxx>(TgjjDwxx.class);
        return util.exportExcel(list, "dwxx");
    }

    /**
     * 新增单位信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存单位信息
     */
    @RequiresPermissions("system:dwxx:add")
    @Log(title = "单位信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjDwxx tgjjDwxx)
    {
        return toAjax(tgjjDwxxService.insertTgjjDwxx(tgjjDwxx));
    }

    /**
     * 修改单位信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjDwxx tgjjDwxx = tgjjDwxxService.selectTgjjDwxxById(ID);
        mmap.put("tgjjDwxx", tgjjDwxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存单位信息
     */
    @RequiresPermissions("system:dwxx:edit")
    @Log(title = "单位信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjDwxx tgjjDwxx)
    {
        return toAjax(tgjjDwxxService.updateTgjjDwxx(tgjjDwxx));
    }

    /**
     * 删除单位信息
     */
    @RequiresPermissions("system:dwxx:remove")
    @Log(title = "单位信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjDwxxService.deleteTgjjDwxxByIds(ids));
    }
}
