package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjGrckzhbdxx;
import com.sooka.system.service.ITgjjGrckzhbdxxService;

/**
 * 个人存款账户变动信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/grckzhbdxx")
public class TgjjGrckzhbdxxController extends BaseController
{
    private String prefix = "system/grckzhbdxx";

    @Autowired
    private ITgjjGrckzhbdxxService tgjjGrckzhbdxxService;

    @RequiresPermissions("system:grckzhbdxx:view")
    @GetMapping()
    public String grckzhbdxx()
    {
        return prefix + "/grckzhbdxx";
    }

    /**
     * 查询个人存款账户变动信息列表
     */
    @RequiresPermissions("system:grckzhbdxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjGrckzhbdxx tgjjGrckzhbdxx)
    {
        startPage();
        List<TgjjGrckzhbdxx> list = tgjjGrckzhbdxxService.selectTgjjGrckzhbdxxList(tgjjGrckzhbdxx);
        return getDataTable(list);
    }

    /**
     * 导出个人存款账户变动信息列表
     */
    @RequiresPermissions("system:grckzhbdxx:export")
    @Log(title = "个人存款账户变动信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjGrckzhbdxx tgjjGrckzhbdxx)
    {
        List<TgjjGrckzhbdxx> list = tgjjGrckzhbdxxService.selectTgjjGrckzhbdxxList(tgjjGrckzhbdxx);
        ExcelUtil<TgjjGrckzhbdxx> util = new ExcelUtil<TgjjGrckzhbdxx>(TgjjGrckzhbdxx.class);
        return util.exportExcel(list, "grckzhbdxx");
    }

    /**
     * 新增个人存款账户变动信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存个人存款账户变动信息
     */
    @RequiresPermissions("system:grckzhbdxx:add")
    @Log(title = "个人存款账户变动信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjGrckzhbdxx tgjjGrckzhbdxx)
    {
        return toAjax(tgjjGrckzhbdxxService.insertTgjjGrckzhbdxx(tgjjGrckzhbdxx));
    }

    /**
     * 修改个人存款账户变动信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjGrckzhbdxx tgjjGrckzhbdxx = tgjjGrckzhbdxxService.selectTgjjGrckzhbdxxById(ID);
        mmap.put("tgjjGrckzhbdxx", tgjjGrckzhbdxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存个人存款账户变动信息
     */
    @RequiresPermissions("system:grckzhbdxx:edit")
    @Log(title = "个人存款账户变动信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjGrckzhbdxx tgjjGrckzhbdxx)
    {
        return toAjax(tgjjGrckzhbdxxService.updateTgjjGrckzhbdxx(tgjjGrckzhbdxx));
    }

    /**
     * 删除个人存款账户变动信息
     */
    @RequiresPermissions("system:grckzhbdxx:remove")
    @Log(title = "个人存款账户变动信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjGrckzhbdxxService.deleteTgjjGrckzhbdxxByIds(ids));
    }
}
