package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjGrdkyqxx;
import com.sooka.system.service.ITgjjGrdkyqxxService;

/**
 * 个人贷款逾期信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/grdkyqxx")
public class TgjjGrdkyqxxController extends BaseController
{
    private String prefix = "system/grdkyqxx";

    @Autowired
    private ITgjjGrdkyqxxService tgjjGrdkyqxxService;

    @RequiresPermissions("system:grdkyqxx:view")
    @GetMapping()
    public String grdkyqxx()
    {
        return prefix + "/grdkyqxx";
    }

    /**
     * 查询个人贷款逾期信息列表
     */
    @RequiresPermissions("system:grdkyqxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjGrdkyqxx tgjjGrdkyqxx)
    {
        startPage();
        List<TgjjGrdkyqxx> list = tgjjGrdkyqxxService.selectTgjjGrdkyqxxList(tgjjGrdkyqxx);
        return getDataTable(list);
    }

    /**
     * 导出个人贷款逾期信息列表
     */
    @RequiresPermissions("system:grdkyqxx:export")
    @Log(title = "个人贷款逾期信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjGrdkyqxx tgjjGrdkyqxx)
    {
        List<TgjjGrdkyqxx> list = tgjjGrdkyqxxService.selectTgjjGrdkyqxxList(tgjjGrdkyqxx);
        ExcelUtil<TgjjGrdkyqxx> util = new ExcelUtil<TgjjGrdkyqxx>(TgjjGrdkyqxx.class);
        return util.exportExcel(list, "grdkyqxx");
    }

    /**
     * 新增个人贷款逾期信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存个人贷款逾期信息
     */
    @RequiresPermissions("system:grdkyqxx:add")
    @Log(title = "个人贷款逾期信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjGrdkyqxx tgjjGrdkyqxx)
    {
        return toAjax(tgjjGrdkyqxxService.insertTgjjGrdkyqxx(tgjjGrdkyqxx));
    }

    /**
     * 修改个人贷款逾期信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjGrdkyqxx tgjjGrdkyqxx = tgjjGrdkyqxxService.selectTgjjGrdkyqxxById(ID);
        mmap.put("tgjjGrdkyqxx", tgjjGrdkyqxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存个人贷款逾期信息
     */
    @RequiresPermissions("system:grdkyqxx:edit")
    @Log(title = "个人贷款逾期信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjGrdkyqxx tgjjGrdkyqxx)
    {
        return toAjax(tgjjGrdkyqxxService.updateTgjjGrdkyqxx(tgjjGrdkyqxx));
    }

    /**
     * 删除个人贷款逾期信息
     */
    @RequiresPermissions("system:grdkyqxx:remove")
    @Log(title = "个人贷款逾期信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjGrdkyqxxService.deleteTgjjGrdkyqxxByIds(ids));
    }
}
