package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjGrdkzhxx;
import com.sooka.system.service.ITgjjGrdkzhxxService;

/**
 * 个人贷款账户信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/grdkzhxx")
public class TgjjGrdkzhxxController extends BaseController
{
    private String prefix = "system/grdkzhxx";

    @Autowired
    private ITgjjGrdkzhxxService tgjjGrdkzhxxService;

    @RequiresPermissions("system:grdkzhxx:view")
    @GetMapping()
    public String grdkzhxx()
    {
        return prefix + "/grdkzhxx";
    }

    /**
     * 查询个人贷款账户信息列表
     */
    @RequiresPermissions("system:grdkzhxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        startPage();
        List<TgjjGrdkzhxx> list = tgjjGrdkzhxxService.selectTgjjGrdkzhxxList(tgjjGrdkzhxx);
        return getDataTable(list);
    }

    /**
     * 导出个人贷款账户信息列表
     */
    @RequiresPermissions("system:grdkzhxx:export")
    @Log(title = "个人贷款账户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        List<TgjjGrdkzhxx> list = tgjjGrdkzhxxService.selectTgjjGrdkzhxxList(tgjjGrdkzhxx);
        ExcelUtil<TgjjGrdkzhxx> util = new ExcelUtil<TgjjGrdkzhxx>(TgjjGrdkzhxx.class);
        return util.exportExcel(list, "grdkzhxx");
    }

    /**
     * 新增个人贷款账户信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存个人贷款账户信息
     */
    @RequiresPermissions("system:grdkzhxx:add")
    @Log(title = "个人贷款账户信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        return toAjax(tgjjGrdkzhxxService.insertTgjjGrdkzhxx(tgjjGrdkzhxx));
    }

    /**
     * 修改个人贷款账户信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjGrdkzhxx tgjjGrdkzhxx = tgjjGrdkzhxxService.selectTgjjGrdkzhxxById(ID);
        mmap.put("tgjjGrdkzhxx", tgjjGrdkzhxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存个人贷款账户信息
     */
    @RequiresPermissions("system:grdkzhxx:edit")
    @Log(title = "个人贷款账户信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        return toAjax(tgjjGrdkzhxxService.updateTgjjGrdkzhxx(tgjjGrdkzhxx));
    }

    /**
     * 删除个人贷款账户信息
     */
    @RequiresPermissions("system:grdkzhxx:remove")
    @Log(title = "个人贷款账户信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjGrdkzhxxService.deleteTgjjGrdkzhxxByIds(ids));
    }
}
