package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjGrxx;
import com.sooka.system.service.ITgjjGrxxService;

/**
 * 个人信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/grxx")
public class TgjjGrxxController extends BaseController
{
    private String prefix = "system/grxx";

    @Autowired
    private ITgjjGrxxService tgjjGrxxService;

    @RequiresPermissions("system:grxx:view")
    @GetMapping()
    public String grxx()
    {
        return prefix + "/grxx";
    }

    /**
     * 查询个人信息列表
     */
    @RequiresPermissions("system:grxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjGrxx tgjjGrxx)
    {
        startPage();
        List<TgjjGrxx> list = tgjjGrxxService.selectTgjjGrxxList(tgjjGrxx);
        return getDataTable(list);
    }

    /**
     * 导出个人信息列表
     */
    @RequiresPermissions("system:grxx:export")
    @Log(title = "个人信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjGrxx tgjjGrxx)
    {
        List<TgjjGrxx> list = tgjjGrxxService.selectTgjjGrxxList(tgjjGrxx);
        ExcelUtil<TgjjGrxx> util = new ExcelUtil<TgjjGrxx>(TgjjGrxx.class);
        return util.exportExcel(list, "grxx");
    }

    /**
     * 新增个人信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存个人信息
     */
    @RequiresPermissions("system:grxx:add")
    @Log(title = "个人信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjGrxx tgjjGrxx)
    {
        return toAjax(tgjjGrxxService.insertTgjjGrxx(tgjjGrxx));
    }

    /**
     * 修改个人信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjGrxx tgjjGrxx = tgjjGrxxService.selectTgjjGrxxById(ID);
        mmap.put("tgjjGrxx", tgjjGrxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存个人信息
     */
    @RequiresPermissions("system:grxx:edit")
    @Log(title = "个人信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjGrxx tgjjGrxx)
    {
        return toAjax(tgjjGrxxService.updateTgjjGrxx(tgjjGrxx));
    }

    /**
     * 删除个人信息
     */
    @RequiresPermissions("system:grxx:remove")
    @Log(title = "个人信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjGrxxService.deleteTgjjGrxxByIds(ids));
    }
}
