package com.sooka.system.funeral.ashes_renew.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.funeral.ashes_renew.domain.TGuijiAshesRenew;
import com.sooka.system.funeral.ashes_renew.service.ITGuijiAshesRenewService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市殡葬-骨灰续存基本信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/funeral/funeral_ashes_renew")
public class TGuijiAshesRenewController extends BaseController
{
    private String prefix = "system/funeral/ashes_renew";

    @Autowired
    private ITGuijiAshesRenewService service;

    @RequiresPermissions("system:funeral_ashes_renew:view")
    @GetMapping()
    public String funeral_ashes_renew()
    {
        return prefix + "/ashes_renew";
    }

    /**
     * 查询市殡葬-骨灰续存基本信息列表
     */
    @RequiresPermissions("system:funeral_ashes_renew:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiAshesRenew param)
    {
        startPage();
        List<TGuijiAshesRenew> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市殡葬-骨灰续存基本信息列表
     */
    @RequiresPermissions("system:funeral_ashes_renew:export")
    @Log(title = "市殡葬-骨灰续存基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiAshesRenew param)
    {
        List<TGuijiAshesRenew> list = service.selectList(param);
        ExcelUtil<TGuijiAshesRenew> util = new ExcelUtil<TGuijiAshesRenew>(TGuijiAshesRenew.class);
        return util.exportExcel(list, "市殡葬-骨灰续存基本信息");
    }

    /**
     * 新增市殡葬-骨灰续存基本信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市殡葬-骨灰续存基本信息
     */
    @RequiresPermissions("system:funeral_ashes_renew:add")
    @Log(title = "市殡葬-骨灰续存基本信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiAshesRenew param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市殡葬-骨灰续存基本信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiAshesRenew param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市殡葬-骨灰续存基本信息
     */
    @RequiresPermissions("system:funeral_ashes_renew:edit")
    @Log(title = "市殡葬-骨灰续存基本信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiAshesRenew param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市殡葬-骨灰续存基本信息
     */
    @RequiresPermissions("system:funeral_ashes_renew:remove")
    @Log(title = "市殡葬-骨灰续存基本信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市殡葬-骨灰续存基本信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiAshesRenew param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
