package com.sooka.system.funeral.pay.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.funeral.pay.domain.TGuijiPay;
import com.sooka.system.funeral.pay.service.ITGuijiPayService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市殡葬-缴费基本信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/funeral/funeral_pay")
public class TGuijiPayController extends BaseController
{
    private String prefix = "system/funeral/pay";

    @Autowired
    private ITGuijiPayService service;

    @RequiresPermissions("system:funeral_pay:view")
    @GetMapping()
    public String funeral_pay()
    {
        return prefix + "/pay";
    }

    /**
     * 查询市殡葬-缴费基本信息列表
     */
    @RequiresPermissions("system:funeral_pay:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiPay param)
    {
        startPage();
        List<TGuijiPay> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市殡葬-缴费基本信息列表
     */
    @RequiresPermissions("system:funeral_pay:export")
    @Log(title = "市殡葬-缴费基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiPay param)
    {
        List<TGuijiPay> list = service.selectList(param);
        ExcelUtil<TGuijiPay> util = new ExcelUtil<TGuijiPay>(TGuijiPay.class);
        return util.exportExcel(list, "市殡葬-缴费基本信息");
    }

    /**
     * 新增市殡葬-缴费基本信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市殡葬-缴费基本信息
     */
    @RequiresPermissions("system:funeral_pay:add")
    @Log(title = "市殡葬-缴费基本信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiPay param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市殡葬-缴费基本信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiPay param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市殡葬-缴费基本信息
     */
    @RequiresPermissions("system:funeral_pay:edit")
    @Log(title = "市殡葬-缴费基本信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiPay param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市殡葬-缴费基本信息
     */
    @RequiresPermissions("system:funeral_pay:remove")
    @Log(title = "市殡葬-缴费基本信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市殡葬-缴费基本信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiPay param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
