package com.sooka.system.gas.aofe_gas_meter_infor.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.gas.aofe_gas_meter_infor.domain.TGuijiAofeGasMeterInfor;
import com.sooka.system.gas.aofe_gas_meter_infor.service.ITGuijiAofeGasMeterInforService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 奥枫收费系统-表具信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/gas/aofe_gas_meter_infor")
public class TGuijiAofeGasMeterInforController extends BaseController
{
    private String prefix = "system/gas/aofe_gas_meter_infor";

    @Autowired
    private ITGuijiAofeGasMeterInforService service;

    @RequiresPermissions("system:aofe_gas_meter_infor:view")
    @GetMapping()
    public String aofe_gas_meter_infor()
    {
        return prefix + "/aofe_gas_meter_infor";
    }

    /**
     * 查询奥枫收费系统-表具信息列表
     */
    @RequiresPermissions("system:aofe_gas_meter_infor:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiAofeGasMeterInfor param)
    {
        startPage();
        List<TGuijiAofeGasMeterInfor> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出奥枫收费系统-表具信息列表
     */
    @RequiresPermissions("system:aofe_gas_meter_infor:export")
    @Log(title = "奥枫收费系统-表具信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiAofeGasMeterInfor param)
    {
        List<TGuijiAofeGasMeterInfor> list = service.selectList(param);
        ExcelUtil<TGuijiAofeGasMeterInfor> util = new ExcelUtil<TGuijiAofeGasMeterInfor>(TGuijiAofeGasMeterInfor.class);
        return util.exportExcel(list, "奥枫收费系统-表具信息");
    }

    /**
     * 新增奥枫收费系统-表具信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存奥枫收费系统-表具信息
     */
    @RequiresPermissions("system:aofe_gas_meter_infor:add")
    @Log(title = "奥枫收费系统-表具信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiAofeGasMeterInfor param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改奥枫收费系统-表具信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiAofeGasMeterInfor param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存奥枫收费系统-表具信息
     */
    @RequiresPermissions("system:aofe_gas_meter_infor:edit")
    @Log(title = "奥枫收费系统-表具信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiAofeGasMeterInfor param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除奥枫收费系统-表具信息
     */
    @RequiresPermissions("system:aofe_gas_meter_infor:remove")
    @Log(title = "奥枫收费系统-表具信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 奥枫收费系统-表具信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiAofeGasMeterInfor param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
