package com.sooka.system.gas.qinchuan_user_infor.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.gas.qinchuan_user_infor.domain.TGuijiQinchuanUserInfor;
import com.sooka.system.gas.qinchuan_user_infor.service.ITGuijiQinchuanUserInforService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 秦川业务系统-用户信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/gas/qinchuan_user_infor")
public class TGuijQinchuanUserInforController extends BaseController
{
    private String prefix = "system/gas/qinchuan_user_infor";

    @Autowired
    private ITGuijiQinchuanUserInforService service;

    @RequiresPermissions("system:qinchuan_user_infor:view")
    @GetMapping()
    public String qinchuan_user_infor()
    {
        return prefix + "/qinchuan_user_infor";
    }

    /**
     * 查询秦川业务系统-用户信息列表
     */
    @RequiresPermissions("system:qinchuan_user_infor:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiQinchuanUserInfor param)
    {
        startPage();
        List<TGuijiQinchuanUserInfor> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出秦川业务系统-用户信息列表
     */
    @RequiresPermissions("system:qinchuan_user_infor:export")
    @Log(title = "秦川业务系统-用户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiQinchuanUserInfor param)
    {
        List<TGuijiQinchuanUserInfor> list = service.selectList(param);
        ExcelUtil<TGuijiQinchuanUserInfor> util = new ExcelUtil<TGuijiQinchuanUserInfor>(TGuijiQinchuanUserInfor.class);
        return util.exportExcel(list, "秦川业务系统-用户信息");
    }

    /**
     * 新增秦川业务系统-用户信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存秦川业务系统-用户信息
     */
    @RequiresPermissions("system:qinchuan_user_infor:add")
    @Log(title = "秦川业务系统-用户信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiQinchuanUserInfor param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改秦川业务系统-用户信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiQinchuanUserInfor param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存秦川业务系统-用户信息
     */
    @RequiresPermissions("system:qinchuan_user_infor:edit")
    @Log(title = "秦川业务系统-用户信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiQinchuanUserInfor param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除秦川业务系统-用户信息
     */
    @RequiresPermissions("system:qinchuan_user_infor:remove")
    @Log(title = "秦川业务系统-用户信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 秦川业务系统-用户信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiQinchuanUserInfor param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
