package com.sooka.system.gas.sc_meter_reading_infor.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.gas.sc_meter_reading_infor.domain.TGuijiSCMeterReadingInfor;
import com.sooka.system.gas.sc_meter_reading_infor.service.ITGuijiSCMeterReadingInforService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 思凯收费系统-抄表信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/gas/sc_meter_reading_infor")
public class TGuijiSCMeterReadingInforController extends BaseController
{
    private String prefix = "system/gas/sc_meter_reading_infor";

    @Autowired
    private ITGuijiSCMeterReadingInforService service;

    @RequiresPermissions("system:sc_meter_reading_infor:view")
    @GetMapping()
    public String sc_meter_reading_infor()
    {
        return prefix + "/sc_meter_reading_infor";
    }

    /**
     * 查询思凯收费系统-列表
     */
    @RequiresPermissions("system:sc_meter_reading_infor:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiSCMeterReadingInfor param)
    {
        startPage();
        List<TGuijiSCMeterReadingInfor> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出思凯收费系统-抄表信息列表
     */
    @RequiresPermissions("system:sc_meter_reading_infor:export")
    @Log(title = "思凯收费系统-抄表信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiSCMeterReadingInfor param)
    {
        List<TGuijiSCMeterReadingInfor> list = service.selectList(param);
        ExcelUtil<TGuijiSCMeterReadingInfor> util = new ExcelUtil<TGuijiSCMeterReadingInfor>(TGuijiSCMeterReadingInfor.class);
        return util.exportExcel(list, "思凯收费系统-抄表信息");
    }

    /**
     * 新增思凯收费系统-抄表信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存思凯收费系统-抄表信息
     */
    @RequiresPermissions("system:sc_meter_reading_infor:add")
    @Log(title = "思凯收费系统-抄表信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiSCMeterReadingInfor param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改思凯收费系统-抄表信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiSCMeterReadingInfor param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存思凯收费系统-抄表信息
     */
    @RequiresPermissions("system:sc_meter_reading_infor:edit")
    @Log(title = "思凯收费系统-抄表信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiSCMeterReadingInfor param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除思凯收费系统-抄表信息
     */
    @RequiresPermissions("system:sc_meter_reading_infor:remove")
    @Log(title = "思凯收费系统-抄表信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 思凯收费系统-抄表信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiSCMeterReadingInfor param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
