package com.sooka.system.gas.xinKer_acceptance_infor.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.gas.xinKer_acceptance_infor.domain.TGuijiXinKerAcceptanceInfor;
import com.sooka.system.gas.xinKer_acceptance_infor.service.ITGuijiXinKerAcceptanceInforService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 鑫科客户系统-受理信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/gas/xinKer_acceptance_infor")
public class TGuijXinKerAcceptanceInforController extends BaseController
{
    private String prefix = "system/gas/xinKer_acceptance_infor";

    @Autowired
    private ITGuijiXinKerAcceptanceInforService service;

    @RequiresPermissions("system:xinKer_acceptance_infor:view")
    @GetMapping()
    public String xinKer_acceptance_infor()
    {
        return prefix + "/xinKer_acceptance_infor";
    }

    /**
     * 查询鑫科客户系统-受理信息列表
     */
    @RequiresPermissions("system:xinKer_acceptance_infor:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiXinKerAcceptanceInfor param)
    {
        startPage();
        List<TGuijiXinKerAcceptanceInfor> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出鑫科客户系统-受理信息列表
     */
    @RequiresPermissions("system:xinKer_acceptance_infor:export")
    @Log(title = "鑫科客户系统-受理信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiXinKerAcceptanceInfor param)
    {
        List<TGuijiXinKerAcceptanceInfor> list = service.selectList(param);
        ExcelUtil<TGuijiXinKerAcceptanceInfor> util = new ExcelUtil<TGuijiXinKerAcceptanceInfor>(TGuijiXinKerAcceptanceInfor.class);
        return util.exportExcel(list, "鑫科客户系统-受理信息");
    }

    /**
     * 新增鑫科客户系统-受理信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存鑫科客户系统-受理信息
     */
    @RequiresPermissions("system:xinKer_acceptance_infor:add")
    @Log(title = "鑫科客户系统-受理信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiXinKerAcceptanceInfor param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改鑫科客户系统-受理信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiXinKerAcceptanceInfor param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存鑫科客户系统-受理信息
     */
    @RequiresPermissions("system:xinKer_acceptance_infor:edit")
    @Log(title = "鑫科客户系统-受理信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiXinKerAcceptanceInfor param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除鑫科客户系统-受理信息
     */
    @RequiresPermissions("system:xinKer_acceptance_infor:remove")
    @Log(title = "鑫科客户系统-受理信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 鑫科客户系统-受理信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiXinKerAcceptanceInfor param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
