package com.sooka.system.gas.xinKer_user_infor.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.gas.xinKer_user_infor.domain.TGuijiXinKerUserInfor;
import com.sooka.system.gas.xinKer_user_infor.service.ITGuijiXinKerUserInforService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 鑫科客户系统-客户信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/gas/xinKer_user_infor")
public class TGuijXinKerUserInforController extends BaseController
{
    private String prefix = "system/gas/xinKer_user_infor";

    @Autowired
    private ITGuijiXinKerUserInforService service;

    @RequiresPermissions("system:xinKer_user_infor:view")
    @GetMapping()
    public String xinKer_user_infor()
    {
        return prefix + "/xinKer_user_infor";
    }

    /**
     * 查询鑫科客户系统-客户信息列表
     */
    @RequiresPermissions("system:xinKer_user_infor:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiXinKerUserInfor param)
    {
        startPage();
        List<TGuijiXinKerUserInfor> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出鑫科客户系统-客户信息列表
     */
    @RequiresPermissions("system:xinKer_user_infor:export")
    @Log(title = "鑫科客户系统-客户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiXinKerUserInfor param)
    {
        List<TGuijiXinKerUserInfor> list = service.selectList(param);
        ExcelUtil<TGuijiXinKerUserInfor> util = new ExcelUtil<TGuijiXinKerUserInfor>(TGuijiXinKerUserInfor.class);
        return util.exportExcel(list, "鑫科客户系统-客户信息");
    }

    /**
     * 新增鑫科客户系统-客户信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存鑫科客户系统-客户信息
     */
    @RequiresPermissions("system:xinKer_user_infor:add")
    @Log(title = "鑫科客户系统-客户信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiXinKerUserInfor param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改鑫科客户系统-客户信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiXinKerUserInfor param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存鑫科客户系统-客户信息
     */
    @RequiresPermissions("system:xinKer_user_infor:edit")
    @Log(title = "鑫科客户系统-客户信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiXinKerUserInfor param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除鑫科客户系统-客户信息
     */
    @RequiresPermissions("system:xinKer_user_infor:remove")
    @Log(title = "鑫科客户系统-客户信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 鑫科客户系统-客户信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiXinKerUserInfor param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
