package com.sooka.system.real_estate.contract_check_out.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.contract_check_out.domain.TGuijiRealEstateContractCheckOut;
import com.sooka.system.real_estate.contract_check_out.service.ITGuijiRealEstateContractCheckOutService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-合同退房信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_contract_check_out")
public class TGuijiRealEstateContractCheckOutController extends BaseController
{
    private String prefix = "system/real_estate/contract_check_out";

    @Autowired
    private ITGuijiRealEstateContractCheckOutService service;

    @RequiresPermissions("system:contract_check_out:view")
    @GetMapping()
    public String contract_check_out()
    {
        return prefix + "/contract_check_out";
    }

    /**
     * 查询市房地产-合同退房信息列表
     */
    @RequiresPermissions("system:contract_check_out:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateContractCheckOut param)
    {
        startPage();
        List<TGuijiRealEstateContractCheckOut> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-合同退房信息列表
     */
    @RequiresPermissions("system:contract_check_out:export")
    @Log(title = "市房地产-合同退房信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateContractCheckOut param)
    {
        List<TGuijiRealEstateContractCheckOut> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateContractCheckOut> util = new ExcelUtil<TGuijiRealEstateContractCheckOut>(TGuijiRealEstateContractCheckOut.class);
        return util.exportExcel(list, "市房地产-合同退房信息");
    }

    /**
     * 新增市房地产-合同退房信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-合同退房信息
     */
    @RequiresPermissions("system:contract_check_out:add")
    @Log(title = "市房地产-合同退房信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateContractCheckOut param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-合同退房信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateContractCheckOut param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-合同退房信息
     */
    @RequiresPermissions("system:contract_check_out:edit")
    @Log(title = "市房地产-合同退房信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateContractCheckOut param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-合同退房信息
     */
    @RequiresPermissions("system:contract_check_out:remove")
    @Log(title = "市房地产-合同退房信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-合同退房信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateContractCheckOut param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
