package com.sooka.system.real_estate.housing_initial.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.housing_initial.domain.TGuijiRealEstateHousingInitial;
import com.sooka.system.real_estate.housing_initial.service.ITGuijiRealEstateHousingInitialService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-商品房初始信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_housing_initial")
public class TGuijiRealEstateHousingInitialController extends BaseController
{
    private String prefix = "system/real_estate/housing_initial";

    @Autowired
    private ITGuijiRealEstateHousingInitialService service;

    @RequiresPermissions("system:housing_initial:view")
    @GetMapping()
    public String housing_initial()
    {
        return prefix + "/housing_initial";
    }

    /**
     * 查询市房地产-商品房初始信息列表
     */
    @RequiresPermissions("system:housing_initial:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateHousingInitial param)
    {
        startPage();
        List<TGuijiRealEstateHousingInitial> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-商品房初始信息列表
     */
    @RequiresPermissions("system:housing_initial:export")
    @Log(title = "市房地产-商品房初始信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateHousingInitial param)
    {
        List<TGuijiRealEstateHousingInitial> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateHousingInitial> util = new ExcelUtil<TGuijiRealEstateHousingInitial>(TGuijiRealEstateHousingInitial.class);
        return util.exportExcel(list, "市房地产-商品房初始信息");
    }

    /**
     * 新增市房地产-商品房初始信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-商品房初始信息
     */
    @RequiresPermissions("system:housing_initial:add")
    @Log(title = "市房地产-商品房初始信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateHousingInitial param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-商品房初始信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateHousingInitial param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-商品房初始信息
     */
    @RequiresPermissions("system:housing_initial:edit")
    @Log(title = "市房地产-商品房初始信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateHousingInitial param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-商品房初始信息
     */
    @RequiresPermissions("system:housing_initial:remove")
    @Log(title = "市房地产-商品房初始信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-商品房初始信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateHousingInitial param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
