package com.sooka.system.real_estate.housing_relocation.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.housing_relocation.domain.TGuijiRealEstateHousingRelocation;
import com.sooka.system.real_estate.housing_relocation.service.ITGuijiRealEstateHousingRelocationService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-回迁房信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_housing_relocation")
public class TGuijiRealEstateHousingRelocationController extends BaseController
{
    private String prefix = "system/real_estate/housing_relocation";

    @Autowired
    private ITGuijiRealEstateHousingRelocationService service;

    @RequiresPermissions("system:housing_relocation:view")
    @GetMapping()
    public String housing_relocation()
    {
        return prefix + "/housing_relocation";
    }

    /**
     * 查询市房地产-回迁房信息列表
     */
    @RequiresPermissions("system:housing_relocation:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateHousingRelocation param)
    {
        startPage();
        List<TGuijiRealEstateHousingRelocation> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-回迁房信息列表
     */
    @RequiresPermissions("system:housing_relocation:export")
    @Log(title = "市房地产-回迁房信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateHousingRelocation param)
    {
        List<TGuijiRealEstateHousingRelocation> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateHousingRelocation> util = new ExcelUtil<TGuijiRealEstateHousingRelocation>(TGuijiRealEstateHousingRelocation.class);
        return util.exportExcel(list, "市房地产-回迁房信息");
    }

    /**
     * 新增市房地产-回迁房信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-回迁房信息
     */
    @RequiresPermissions("system:housing_relocation:add")
    @Log(title = "市房地产-回迁房信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateHousingRelocation param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-回迁房信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateHousingRelocation param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-回迁房信息
     */
    @RequiresPermissions("system:housing_relocation:edit")
    @Log(title = "市房地产-回迁房信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateHousingRelocation param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-回迁房信息
     */
    @RequiresPermissions("system:housing_relocation:remove")
    @Log(title = "市房地产-回迁房信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-回迁房信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateHousingRelocation param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
