package com.sooka.system.real_estate.mortgage_cancel.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.mortgage_cancel.domain.TGuijiRealEstateMortgageCancel;
import com.sooka.system.real_estate.mortgage_cancel.service.ITGuijiRealEstateMortgageCancelService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-一般抵押权注销信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_mortgage_cancel")
public class TGuijiRealEstateMortgageCancelController extends BaseController
{
    private String prefix = "system/real_estate/mortgage_cancel";

    @Autowired
    private ITGuijiRealEstateMortgageCancelService service;

    @RequiresPermissions("system:mortgage_cancel:view")
    @GetMapping()
    public String mortgage_cancel()
    {
        return prefix + "/mortgage_cancel";
    }

    /**
     * 查询市房地产-一般抵押权注销信息列表
     */
    @RequiresPermissions("system:mortgage_cancel:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateMortgageCancel param)
    {
        startPage();
        List<TGuijiRealEstateMortgageCancel> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-一般抵押权注销信息列表
     */
    @RequiresPermissions("system:mortgage_cancel:export")
    @Log(title = "市房地产-一般抵押权注销信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateMortgageCancel param)
    {
        List<TGuijiRealEstateMortgageCancel> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateMortgageCancel> util = new ExcelUtil<TGuijiRealEstateMortgageCancel>(TGuijiRealEstateMortgageCancel.class);
        return util.exportExcel(list, "市房地产-一般抵押权注销信息");
    }

    /**
     * 新增市房地产-一般抵押权注销信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-一般抵押权注销信息
     */
    @RequiresPermissions("system:mortgage_cancel:add")
    @Log(title = "市房地产-一般抵押权注销信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateMortgageCancel param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-一般抵押权注销信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateMortgageCancel param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-一般抵押权注销信息
     */
    @RequiresPermissions("system:mortgage_cancel:edit")
    @Log(title = "市房地产-一般抵押权注销信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateMortgageCancel param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-一般抵押权注销信息
     */
    @RequiresPermissions("system:mortgage_cancel:remove")
    @Log(title = "市房地产-一般抵押权注销信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-一般抵押权注销信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateMortgageCancel param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
