package com.sooka.system.real_estate.mortgage_change.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.mortgage_change.domain.TGuijiRealEstateMortgageChange;
import com.sooka.system.real_estate.mortgage_change.service.ITGuijiRealEstateMortgageChangeService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-一般抵押权变更信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_mortgage_change")
public class TGuijiRealEstateMortgageChangeController extends BaseController
{
    private String prefix = "system/real_estate/mortgage_change";

    @Autowired
    private ITGuijiRealEstateMortgageChangeService service;

    @RequiresPermissions("system:mortgage_change:view")
    @GetMapping()
    public String mortgage_change()
    {
        return prefix + "/mortgage_change";
    }

    /**
     * 查询市房地产-一般抵押权变更信息列表
     */
    @RequiresPermissions("system:mortgage_change:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateMortgageChange param)
    {
        startPage();
        List<TGuijiRealEstateMortgageChange> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-一般抵押权变更信息列表
     */
    @RequiresPermissions("system:mortgage_change:export")
    @Log(title = "市房地产-一般抵押权变更信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateMortgageChange param)
    {
        List<TGuijiRealEstateMortgageChange> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateMortgageChange> util = new ExcelUtil<TGuijiRealEstateMortgageChange>(TGuijiRealEstateMortgageChange.class);
        return util.exportExcel(list, "市房地产-一般抵押权变更信息");
    }

    /**
     * 新增市房地产-一般抵押权变更信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-一般抵押权变更信息
     */
    @RequiresPermissions("system:mortgage_change:add")
    @Log(title = "市房地产-一般抵押权变更信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateMortgageChange param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-一般抵押权变更信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateMortgageChange param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-一般抵押权变更信息
     */
    @RequiresPermissions("system:mortgage_change:edit")
    @Log(title = "市房地产-一般抵押权变更信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateMortgageChange param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-一般抵押权变更信息
     */
    @RequiresPermissions("system:mortgage_change:remove")
    @Log(title = "市房地产-一般抵押权变更信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-一般抵押权变更信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateMortgageChange param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
