package com.sooka.system.real_estate.mortgage_construction.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.mortgage_construction.domain.TGuijiRealEstateMortgageConstruction;
import com.sooka.system.real_estate.mortgage_construction.service.ITGuijiRealEstateMortgageConstructionService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-在建工程抵押信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_mortgage_construction")
public class TGuijiRealEstateMortgageConstructionController extends BaseController
{
    private String prefix = "system/real_estate/mortgage_construction";

    @Autowired
    private ITGuijiRealEstateMortgageConstructionService service;

    @RequiresPermissions("system:mortgage_construction:view")
    @GetMapping()
    public String mortgage_construction()
    {
        return prefix + "/mortgage_construction";
    }

    /**
     * 查询市房地产-在建工程抵押信息列表
     */
    @RequiresPermissions("system:mortgage_construction:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateMortgageConstruction param)
    {
        startPage();
        List<TGuijiRealEstateMortgageConstruction> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-在建工程抵押信息列表
     */
    @RequiresPermissions("system:mortgage_construction:export")
    @Log(title = "市房地产-在建工程抵押信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateMortgageConstruction param)
    {
        List<TGuijiRealEstateMortgageConstruction> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateMortgageConstruction> util = new ExcelUtil<TGuijiRealEstateMortgageConstruction>(TGuijiRealEstateMortgageConstruction.class);
        return util.exportExcel(list, "市房地产-在建工程抵押信息");
    }

    /**
     * 新增市房地产-在建工程抵押信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-在建工程抵押信息
     */
    @RequiresPermissions("system:mortgage_construction:add")
    @Log(title = "市房地产-在建工程抵押信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateMortgageConstruction param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-在建工程抵押信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateMortgageConstruction param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-在建工程抵押信息
     */
    @RequiresPermissions("system:mortgage_construction:edit")
    @Log(title = "市房地产-在建工程抵押信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateMortgageConstruction param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-在建工程抵押信息
     */
    @RequiresPermissions("system:mortgage_construction:remove")
    @Log(title = "市房地产-在建工程抵押信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-在建工程抵押信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateMortgageConstruction param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
