package com.sooka.system.real_estate.mortgage_construction.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.system.real_estate.mortgage_construction.domain.TGuijiRealEstateMortgageConstruction;
import com.sooka.system.real_estate.mortgage_construction.mapper.TGuijiRealEstateMortgageConstructionMapper;
import com.sooka.system.real_estate.mortgage_construction.service.ITGuijiRealEstateMortgageConstructionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 市房地产-在建工程抵押信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiRealEstateMortgageConstructionServiceImpl implements ITGuijiRealEstateMortgageConstructionService
{
    @Autowired
    private TGuijiRealEstateMortgageConstructionMapper mapper;

    /**
     * 查询市房地产-在建工程抵押信息
     *
     * @param id 市房地产-在建工程抵押信息ID
     * @return 市房地产-在建工程抵押信息
     */
    @Override
    public TGuijiRealEstateMortgageConstruction selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询市房地产-在建工程抵押信息列表
     *
     * @param param 市房地产-在建工程抵押信息
     * @return 市房地产-在建工程抵押信息
     */
    @Override
    public List<TGuijiRealEstateMortgageConstruction> selectList(TGuijiRealEstateMortgageConstruction param)
    {
        return mapper.selectList(param);
    }

    /**
     * 新增市房地产-在建工程抵押信息
     *
     * @param param 市房地产-在建工程抵押信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiRealEstateMortgageConstruction param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改市房地产-在建工程抵押信息
     *
     * @param param 市房地产-在建工程抵押信息
     * @return 结果
     */
    @Override
    public int update(TGuijiRealEstateMortgageConstruction param)
    {
        return mapper.update(param);
    }

    /**
     * 删除市房地产-在建工程抵押信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除市房地产-在建工程抵押信息信息
     *
     * @param id 市房地产-在建工程抵押信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
