package com.sooka.system.real_estate.on_sale_record.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.on_sale_record.domain.TGuijiRealEstateOnSaleRecord;
import com.sooka.system.real_estate.on_sale_record.service.ITGuijiRealEstateOnSaleRecordService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-现售备案信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_on_sale_record")
public class TGuijiRealEstateOnSaleRecordController extends BaseController
{
    private String prefix = "system/real_estate/on_sale_record";

    @Autowired
    private ITGuijiRealEstateOnSaleRecordService service;

    @RequiresPermissions("system:on_sale_record:view")
    @GetMapping()
    public String on_sale_record()
    {
        return prefix + "/on_sale_record";
    }

    /**
     * 查询市房地产-现售备案信息列表
     */
    @RequiresPermissions("system:on_sale_record:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateOnSaleRecord param)
    {
        startPage();
        List<TGuijiRealEstateOnSaleRecord> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-现售备案信息列表
     */
    @RequiresPermissions("system:on_sale_record:export")
    @Log(title = "市房地产-现售备案信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateOnSaleRecord param)
    {
        List<TGuijiRealEstateOnSaleRecord> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateOnSaleRecord> util = new ExcelUtil<TGuijiRealEstateOnSaleRecord>(TGuijiRealEstateOnSaleRecord.class);
        return util.exportExcel(list, "市房地产-现售备案信息");
    }

    /**
     * 新增市房地产-现售备案信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-现售备案信息
     */
    @RequiresPermissions("system:on_sale_record:add")
    @Log(title = "市房地产-现售备案信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateOnSaleRecord param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-现售备案信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateOnSaleRecord param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-现售备案信息
     */
    @RequiresPermissions("system:on_sale_record:edit")
    @Log(title = "市房地产-现售备案信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateOnSaleRecord param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-现售备案信息
     */
    @RequiresPermissions("system:on_sale_record:remove")
    @Log(title = "市房地产-现售备案信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-现售备案信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateOnSaleRecord param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
