package com.sooka.system.real_estate.pre_order_cancel_mortgage.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.pre_order_cancel_mortgage.domain.TGuijiRealEstatePreOrderCancelMortgage;
import com.sooka.system.real_estate.pre_order_cancel_mortgage.service.ITGuijiRealEstatePreOrderCancelMortgageService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-预购商品房抵押权注销信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_pre_order_cancel_mortgage")
public class TGuijiRealEstatePreOrderCancelMortgageController extends BaseController
{
    private String prefix = "system/real_estate/pre_order_cancel_mortgage";

    @Autowired
    private ITGuijiRealEstatePreOrderCancelMortgageService service;

    @RequiresPermissions("system:pre_order_cancel_mortgage:view")
    @GetMapping()
    public String pre_order_cancel_mortgage()
    {
        return prefix + "/pre_order_cancel_mortgage";
    }

    /**
     * 查询市房地产-预购商品房抵押权注销信息列表
     */
    @RequiresPermissions("system:pre_order_cancel_mortgage:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstatePreOrderCancelMortgage param)
    {
        startPage();
        List<TGuijiRealEstatePreOrderCancelMortgage> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-预购商品房抵押权注销信息列表
     */
    @RequiresPermissions("system:pre_order_cancel_mortgage:export")
    @Log(title = "市房地产-预购商品房抵押权注销信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstatePreOrderCancelMortgage param)
    {
        List<TGuijiRealEstatePreOrderCancelMortgage> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstatePreOrderCancelMortgage> util = new ExcelUtil<TGuijiRealEstatePreOrderCancelMortgage>(TGuijiRealEstatePreOrderCancelMortgage.class);
        return util.exportExcel(list, "市房地产-预购商品房抵押权注销信息");
    }

    /**
     * 新增市房地产-预购商品房抵押权注销信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-预购商品房抵押权注销信息
     */
    @RequiresPermissions("system:pre_order_cancel_mortgage:add")
    @Log(title = "市房地产-预购商品房抵押权注销信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstatePreOrderCancelMortgage param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-预购商品房抵押权注销信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreOrderCancelMortgage param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-预购商品房抵押权注销信息
     */
    @RequiresPermissions("system:pre_order_cancel_mortgage:edit")
    @Log(title = "市房地产-预购商品房抵押权注销信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstatePreOrderCancelMortgage param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-预购商品房抵押权注销信息
     */
    @RequiresPermissions("system:pre_order_cancel_mortgage:remove")
    @Log(title = "市房地产-预购商品房抵押权注销信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-预购商品房抵押权注销信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreOrderCancelMortgage param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
