package com.sooka.system.real_estate.pre_order_cancel_notice.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.pre_order_cancel_notice.domain.TGuijiRealEstatePreOrderCancelNotice;
import com.sooka.system.real_estate.pre_order_cancel_notice.service.ITGuijiRealEstatePreOrderCancelNoticeService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-预购商品房预告注销信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_pre_order_cancel_notice")
public class TGuijiRealEstatePreOrderCancelNoticeController extends BaseController
{
    private String prefix = "system/real_estate/pre_order_cancel_notice";

    @Autowired
    private ITGuijiRealEstatePreOrderCancelNoticeService service;

    @RequiresPermissions("system:pre_order_cancel_notice:view")
    @GetMapping()
    public String pre_order_cancel_notice()
    {
        return prefix + "/pre_order_cancel_notice";
    }

    /**
     * 查询市房地产-预购商品房预告注销信息列表
     */
    @RequiresPermissions("system:pre_order_cancel_notice:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstatePreOrderCancelNotice param)
    {
        startPage();
        List<TGuijiRealEstatePreOrderCancelNotice> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-预购商品房预告注销信息列表
     */
    @RequiresPermissions("system:pre_order_cancel_notice:export")
    @Log(title = "市房地产-预购商品房预告注销信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstatePreOrderCancelNotice param)
    {
        List<TGuijiRealEstatePreOrderCancelNotice> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstatePreOrderCancelNotice> util = new ExcelUtil<TGuijiRealEstatePreOrderCancelNotice>(TGuijiRealEstatePreOrderCancelNotice.class);
        return util.exportExcel(list, "市房地产-预购商品房预告注销信息");
    }

    /**
     * 新增市房地产-预购商品房预告注销信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-预购商品房预告注销信息
     */
    @RequiresPermissions("system:pre_order_cancel_notice:add")
    @Log(title = "市房地产-预购商品房预告注销信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstatePreOrderCancelNotice param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-预购商品房预告注销信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreOrderCancelNotice param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-预购商品房预告注销信息
     */
    @RequiresPermissions("system:pre_order_cancel_notice:edit")
    @Log(title = "市房地产-预购商品房预告注销信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstatePreOrderCancelNotice param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-预购商品房预告注销信息
     */
    @RequiresPermissions("system:pre_order_cancel_notice:remove")
    @Log(title = "市房地产-预购商品房预告注销信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-预购商品房预告注销信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreOrderCancelNotice param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
