package com.sooka.system.real_estate.pre_sale.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.pre_sale.domain.TGuijiRealEstatePreSale;
import com.sooka.system.real_estate.pre_sale.service.ITGuijiRealEstatePreSaleService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-预售信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_pre_sale")
public class TGuijiRealEstatePreSaleController extends BaseController
{
    private String prefix = "system/real_estate/pre_sale";

    @Autowired
    private ITGuijiRealEstatePreSaleService service;

    @RequiresPermissions("system:pre_sale:view")
    @GetMapping()
    public String pre_sale()
    {
        return prefix + "/pre_sale";
    }

    /**
     * 查询市房地产-预售信息列表
     */
    @RequiresPermissions("system:pre_sale:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstatePreSale param)
    {
        startPage();
        List<TGuijiRealEstatePreSale> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-预售信息列表
     */
    @RequiresPermissions("system:pre_sale:export")
    @Log(title = "市房地产-预售信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstatePreSale param)
    {
        List<TGuijiRealEstatePreSale> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstatePreSale> util = new ExcelUtil<TGuijiRealEstatePreSale>(TGuijiRealEstatePreSale.class);
        return util.exportExcel(list, "市房地产-预售信息");
    }

    /**
     * 新增市房地产-预售信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-预售信息
     */
    @RequiresPermissions("system:pre_sale:add")
    @Log(title = "市房地产-预售信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstatePreSale param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-预售信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreSale param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-预售信息
     */
    @RequiresPermissions("system:pre_sale:edit")
    @Log(title = "市房地产-预售信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstatePreSale param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-预售信息
     */
    @RequiresPermissions("system:pre_sale:remove")
    @Log(title = "市房地产-预售信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-预售信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreSale param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
