package com.sooka.system.real_estate.pre_sale_additional.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.pre_sale_additional.domain.TGuijiRealEstatePreSaleAdditional;
import com.sooka.system.real_estate.pre_sale_additional.service.ITGuijiRealEstatePreSaleAdditionalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-预售补录信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_pre_sale_additional")
public class TGuijiRealEstatePreSaleAdditionalController extends BaseController
{
    private String prefix = "system/real_estate/pre_sale_additional";

    @Autowired
    private ITGuijiRealEstatePreSaleAdditionalService service;

    @RequiresPermissions("system:pre_sale_additional:view")
    @GetMapping()
    public String pre_sale_additional()
    {
        return prefix + "/pre_sale_additional";
    }

    /**
     * 查询市房地产-预售补录信息列表
     */
    @RequiresPermissions("system:pre_sale_additional:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstatePreSaleAdditional param)
    {
        startPage();
        List<TGuijiRealEstatePreSaleAdditional> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-预售补录信息列表
     */
    @RequiresPermissions("system:pre_sale_additional:export")
    @Log(title = "市房地产-预售补录信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstatePreSaleAdditional param)
    {
        List<TGuijiRealEstatePreSaleAdditional> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstatePreSaleAdditional> util = new ExcelUtil<TGuijiRealEstatePreSaleAdditional>(TGuijiRealEstatePreSaleAdditional.class);
        return util.exportExcel(list, "市房地产-预售补录信息");
    }

    /**
     * 新增市房地产-预售补录信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-预售补录信息
     */
    @RequiresPermissions("system:pre_sale_additional:add")
    @Log(title = "市房地产-预售补录信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstatePreSaleAdditional param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-预售补录信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreSaleAdditional param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-预售补录信息
     */
    @RequiresPermissions("system:pre_sale_additional:edit")
    @Log(title = "市房地产-预售补录信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstatePreSaleAdditional param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-预售补录信息
     */
    @RequiresPermissions("system:pre_sale_additional:remove")
    @Log(title = "市房地产-预售补录信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-预售补录信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreSaleAdditional param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
