package com.sooka.system.real_estate.pre_to_on.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.pre_to_on.domain.TGuijiRealEstatePreToOn;
import com.sooka.system.real_estate.pre_to_on.service.ITGuijiRealEstatePreToOnService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-预转现信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_pre_to_on")
public class TGuijiRealEstatePreToOnController extends BaseController
{
    private String prefix = "system/real_estate/pre_to_on";

    @Autowired
    private ITGuijiRealEstatePreToOnService service;

    @RequiresPermissions("system:pre_to_on:view")
    @GetMapping()
    public String pre_to_on()
    {
        return prefix + "/pre_to_on";
    }

    /**
     * 查询市房地产-预转现信息列表
     */
    @RequiresPermissions("system:pre_to_on:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstatePreToOn param)
    {
        startPage();
        List<TGuijiRealEstatePreToOn> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-预转现信息列表
     */
    @RequiresPermissions("system:pre_to_on:export")
    @Log(title = "市房地产-预转现信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstatePreToOn param)
    {
        List<TGuijiRealEstatePreToOn> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstatePreToOn> util = new ExcelUtil<TGuijiRealEstatePreToOn>(TGuijiRealEstatePreToOn.class);
        return util.exportExcel(list, "市房地产-预转现信息");
    }

    /**
     * 新增市房地产-预转现信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-预转现信息
     */
    @RequiresPermissions("system:pre_to_on:add")
    @Log(title = "市房地产-预转现信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstatePreToOn param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-预转现信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreToOn param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-预转现信息
     */
    @RequiresPermissions("system:pre_to_on:edit")
    @Log(title = "市房地产-预转现信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstatePreToOn param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-预转现信息
     */
    @RequiresPermissions("system:pre_to_on:remove")
    @Log(title = "市房地产-预转现信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-预转现信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstatePreToOn param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
