package com.sooka.system.real_estate.record_additional.controller;

import com.sooka.common.annotation.Log;
import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import com.sooka.system.real_estate.record_additional.domain.TGuijiRealEstateRecordAdditional;
import com.sooka.system.real_estate.record_additional.service.ITGuijiRealEstateRecordAdditionalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 市房地产-备案补录信息Controller
 *
 * @author lei
 * @date 2022-08-22
 */
@Controller
@RequestMapping("/system/real_estate/real_estate_record_additional")
public class TGuijiRealEstateRecordAdditionalController extends BaseController
{
    private String prefix = "system/real_estate/record_additional";

    @Autowired
    private ITGuijiRealEstateRecordAdditionalService service;

    @RequiresPermissions("system:record_additional:view")
    @GetMapping()
    public String record_additional()
    {
        return prefix + "/record_additional";
    }

    /**
     * 查询市房地产-备案补录信息列表
     */
    @RequiresPermissions("system:record_additional:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TGuijiRealEstateRecordAdditional param)
    {
        startPage();
        List<TGuijiRealEstateRecordAdditional> list = service.selectList(param);
        return getDataTable(list);
    }

    /**
     * 导出市房地产-备案补录信息列表
     */
    @RequiresPermissions("system:record_additional:export")
    @Log(title = "市房地产-备案补录信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TGuijiRealEstateRecordAdditional param)
    {
        List<TGuijiRealEstateRecordAdditional> list = service.selectList(param);
        ExcelUtil<TGuijiRealEstateRecordAdditional> util = new ExcelUtil<TGuijiRealEstateRecordAdditional>(TGuijiRealEstateRecordAdditional.class);
        return util.exportExcel(list, "市房地产-备案补录信息");
    }

    /**
     * 新增市房地产-备案补录信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存市房地产-备案补录信息
     */
    @RequiresPermissions("system:record_additional:add")
    @Log(title = "市房地产-备案补录信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TGuijiRealEstateRecordAdditional param)
    {
        return toAjax(service.insert(param));
    }

    /**
     * 修改市房地产-备案补录信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateRecordAdditional param = service.selectById(id);
        mmap.put("param", param);
        return prefix + "/edit";
    }

    /**
     * 修改保存市房地产-备案补录信息
     */
    @RequiresPermissions("system:record_additional:edit")
    @Log(title = "市房地产-备案补录信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TGuijiRealEstateRecordAdditional param)
    {
        return toAjax(service.update(param));
    }

    /**
     * 删除市房地产-备案补录信息
     */
    @RequiresPermissions("system:record_additional:remove")
    @Log(title = "市房地产-备案补录信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(service.deleteByIds(ids));
    }

    /**
     * 市房地产-备案补录信息详情
     */
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap)
    {
        TGuijiRealEstateRecordAdditional param = service.selectById(id);
        mmap.put("detail", param);
        return prefix + "/detail";
    }
}
